@@ -17,7 +17,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0R (Compaq Armada M700)
  *
-$Id: battstat.h,v 1.14 2002/02/16 18:18:48 kevinv Exp $
+$Id: battstat.h,v 1.15 2002/02/24 04:20:21 hadess Exp $
  */
 
 #define DEBUG 0
@@ -134,6 +134,13 @@ typedef struct _ProgressData {
   GtkWidget *testhscale;
   GtkObject *testadj;
   GtkWidget *beep_toggle;
+  /* last_* for the benefit of the timeout functions */
+  guint flash;
+  guint last_batt_life;
+  guint last_acline_status;
+  guint last_batt_state;
+  guint last_pixmap_index;
+  guint last_charging;
 } ProgressData;
 
 enum statusimagename {BATTERY,AC,FLASH,WARNING};
